# truffle-react-scripts
[![npm](https://img.shields.io/npm/v/truffle-react-scripts.svg)](https://www.npmjs.com/package/truffle-react-scripts)
[![npm](https://img.shields.io/npm/dm/truffle-react-scripts.svg)](https://www.npmjs.com/package/truffle-react-scripts)

This package includes scripts and configuration used by [Create React App]

## Installation

1. Install Create-React-App and Truffle globally.
    ```javascript
    npm install -g create-react-app
    npm install -g truffle
    ```
2. Create a new dApp.
    ```javascript
    create-react-app my-dapp --scripts-version truffle-react-scripts
    ```
3. Run the development console.
    ```javascript
    truffle develop
    ```
4. Compile and migrate the smart contracts. Note inside the development console we don't preface commands with `truffle`.
    ```javascript
    compile
    migrate
    ```
5. Run the webpack server for front-end hot reloading (outside the development console). Smart contract changes must be manually recompiled and migrated.
    ```javascript
    // Serves the front-end on http://localhost:3000
    npm run start
    ```
6. Truffle can run tests written in Solidity or JavaScript against your smart contracts. Note the command varies slightly if you're in or outside of the development console.
    ```javascript
    // If inside the development console.
    test

    // If outside the development console..
    truffle test
    ```
7. Jest is included for testing React components. Compile your contracts before running Jest, or you may receive some file not found errors.
    ```javascript
    // Run Jest outside of the development console for front-end component tests.
    npm run test
    ```
8. To build the application for production, use the build command. A production build will be in the build_webpack folder.
    ```javascript
    npm run build
    ```

## FAQ

* __How do I use this with the EthereumJS TestRPC?__

    It's as easy as modifying the config file! [Check the documentation on adding network configurations](http://truffleframework.com/docs/advanced/configuration#networks). Depending on the port you're using, you'll also need to update line 24 of `src/utils/getWeb3.js`.

* __Why is there both a truffle.js file and a truffle-config.js file?__

    `truffle-config.js` is a copy of `truffle.js` for compatibility with Windows development environments. Feel free to it if it's irrelevant to your platform.  


```    
my-dapp/
  LICENSE
  package.json
  README.md
  truffle.js
  truffle-config.js
  node_modules/
  build/
    contracts/
      Migrations.json
      SimpleStorage.json
  client/
    public/
      index.html
      favicon.png
    src/
      App.css
      App.js
      App.test.js
      index.css
      index.js
      ../../build/contracts/
      util/
        getWeb3.js
  contracts/
    Migrations.sol
    SimpleStorage.sol
  migrations/
    1_initial_migration.js
    2_deploy_contracts.js
  test/
    simplestorage.js
    TestSimpleStorage.sol
```


- [Getting Started](https://github.com/facebook/create-react-app/blob/master/README.md#getting-started) – How to create a new React app.
- [Truffle](https://truffleframework.com/docs/truffle/overview) – Start using truffle suite.
- [Truffle Boxes](https://github.com/truffle-box/react-box) – Take a look to Truffle Boxes. Another great way to start developing dApps.
- [User Guide](https://github.com/facebook/create-react-app/blob/master/packages/react-scripts/template/README.md) – How to develop apps bootstrapped with Create React App.
